<div id="top"></div>

<!-- PROJECT SHIELDS -->

<!-- PROJECT LOGO -->
<br />
<div align="center">
  <h3 align="center">UzEduCorpus</h3>
  
</div>

```
from UzEduCorpus import UzEduCorpus
print(UzEduCorpus.load_1());
print(UzEduCorpus.load_2());
# ...
print(UzEduCorpus.load_9());
```